/*
 *	wiiuse
 *
 *	Written By:
 *		Michael Laforest	< para >
 *		Email: < thepara (--AT--) g m a i l [--DOT--] com >
 *
 *	Copyright 2005
 *
 *	This file is part of wiiuse.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *	$Header$
 *
 */

/**
 *	@file
 *	@brief General definitions.
 */

#ifndef DEFINITIONS_H_INCLUDED
#define DEFINITIONS_H_INCLUDED

/* this is wiiuse - used to distinguish from third party programs using wiiuse.h */
#define __WIIUSE__

/* uncomment the following line to enable debugging */
//#define _DEBUG_

#include "os.h"

/**
 *	Error output macros.
 */
#define ERROR(fmt, ...)		fprintf(stderr, "[ERROR] " __FILE__ ":%i: " fmt "\n",	\
									__LINE__, ##__VA_ARGS__)

#define SET_ERRNO(wm, e)		wm->errno = e
#define RET_ERRNO(wm, e, ret)	do { wm->errno = e; return ret; } while (0)
#define RETN_ERRNO(wm, e)		do { wm->errno = e; return; } while (0)


/**
 *	Warning output macros.
 */
#define WARNING(fmt, ...)	fprintf(stderr, "[WARNING] " __FILE__ ":%i: " fmt "\n",	\
									__LINE__, ##__VA_ARGS__)

/**
 *	Information output macros.
 */
#define INFO(fmt, ...)		fprintf(stderr, "[INFO] " fmt "\n", ##__VA_ARGS__)

#ifdef _DEBUG_
	#define DEBUG(fmt, ...)	fprintf(stderr, "[DEBUG] " __FILE__ ":%i: " fmt "\n",	\
									__LINE__, ##__VA_ARGS__)
#else
	#define DEBUG(fmt, ...)
#endif


#define WIIMOTE_PI			3.14159265f

/**
 *	Convert from radians to degrees.
 */
#define RAD_TO_DEGREE(r)	((r * 180.0f) / WIIMOTE_PI)

#define absf(x)				((x >= 0) ? (x) : (x * -1.0f))


#endif // DEFINITIONS_H_INCLUDED
