/*
 *	wiiuse
 *
 *	Written By:
 *		Michael Laforest	< para >
 *		Email: < thepara (--AT--) g m a i l [--DOT--] com >
 *
 *	Copyright 2005
 *
 *	This file is part of wiiuse.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *	$Header$
 *
 */

/**
 *	@file
 *	@brief Module entry point.
 *
 *	The file includes functions that should be called
 *	by third party programs using wiiuse as a library.
 */

#include "wiiuse_internal.h"
#include "connect.h"
#include "events.h"

/**
 *	@brief API data
 *
 *	This is what the \a api struct passed to wiiuse_main()
 *	will point to when it is called.
 */
struct wiiuse_api_t wiiuse_api = {
	/* version info */
	WIIUSE_VERSION,
	WIIUSE_API_VERSION,

	/* functions */
	wiimote_init,
	wiimote_disconnected,
	wiimote_rumble,
	wiimote_toggle_rumble,
	wiimote_set_leds,
	wiimote_motion_sensing,
	wiimote_read_data,
	wiimote_write_data,
	wiimote_status,
	wiimote_get_by_id,
	wiimote_get_errno_str,

	wiimote_find,
	wiimote_connect,
	wiimote_disconnect,

	wiimote_poll
};


/**
 *	@brief Module entry point.
 *
 *	@param api Double pointer to an empty api struct.
 *
 *	@return 1 on success, 0 on failure
 *
 *	Load the function pointers into the \a api struct passed.
 */
int wiiuse_main(struct wiiuse_api_t** api) {
	if (!api)
		return 0;

	*api = &wiiuse_api;

	return 1;
}
